AssistantMessageEvent class final

Inheritance

Constructors

AssistantMessageEvent({required String id, required String timestamp, String? parentId, bool ephemeral = false, required String messageId, required String content, List? toolRequests, String? reasoningOpaque, String? reasoningText, String? encryptedContent, String? phase, String? parentToolCallId})
const

Properties

content String
final
encryptedContent String?
final
ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
messageId String
final
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
parentToolCallId String?
final
phase String?
final
reasoningOpaque String?
final
reasoningText String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
ISO-8601 timestamp.
finalinherited
toolRequests List?
final
type String
Event type discriminator.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited