AssistantReply class

Represents a complete assistant reply.

Deprecated: Use AssistantMessageEvent directly instead. CopilotSession.sendAndWait now returns AssistantMessageEvent? to match the upstream SDK behavior.

Annotations
  • @Deprecated('Use AssistantMessageEvent directly from sendAndWait instead')

Constructors

AssistantReply({required String content, String? messageId})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
messageId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited