BaseHookInput class

Base fields present on all hook inputs from the CLI.

Implementers

Constructors

BaseHookInput({required num timestamp, required String cwd})
const

Properties

cwd String
Working directory of the session.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp num
Unix timestamp (milliseconds since epoch) when the hook was triggered.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited