ErrorOccurredInput class

Input for the errorOccurred hook.

Inheritance

Constructors

ErrorOccurredInput({required num timestamp, required String cwd, required String error, required String errorContext, bool recoverable = false})
const
ErrorOccurredInput.fromJson(Map<String, dynamic> json)
factory

Properties

cwd String
Working directory of the session.
finalinherited
error String
Error message.
final
errorContext String
"model_call", "tool_execution", "system", or "user_input".
final
hashCode int
The hash code for this object.
no setterinherited
recoverable bool
Whether the error is recoverable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp num
Unix timestamp (milliseconds since epoch) when the hook was triggered.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited