MessageDeliveryMode enum

Options for sending a message. Message delivery mode for session.send.

This controls how the message is delivered to the session queue. Not to be confused with AgentMode which controls the agent's operating behavior (interactive/plan/autopilot).

Inheritance
Available extensions

Values

enqueue → const MessageDeliveryMode

Add to queue (default).

immediate → const MessageDeliveryMode

Send immediately, bypassing the queue.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonValue() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String value) MessageDeliveryMode

Constants

values → const List<MessageDeliveryMode>
A constant List of the values in this enum, in order of their declaration.