SessionSnapshotRewindEvent class final

Inheritance

Constructors

SessionSnapshotRewindEvent({required String id, required String timestamp, String? parentId, bool ephemeral = true, required String upToEventId, required int eventsRemoved})
const

Properties

ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
eventsRemoved int
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
ISO-8601 timestamp.
finalinherited
type String
Event type discriminator.
finalinherited
upToEventId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited