ToolExecutionStartEvent class final
- Inheritance
-
- Object
- SessionEvent
- ToolExecutionStartEvent
Constructors
Properties
- arguments → dynamic
-
final
- ephemeral → bool
-
Whether this event is ephemeral (not persisted in session history).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique event ID.
finalinherited
- mcpServerName → String?
-
final
- mcpToolName → String?
-
final
- parentId → String?
-
Parent event ID (for nested events like tool execution under a turn).
finalinherited
- parentToolCallId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String
-
ISO-8601 timestamp.
finalinherited
- toolCallId → String
-
final
- toolName → String
-
final
- type → String
-
Event type discriminator.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited