AssistantUsageEvent class final

Inheritance

Constructors

AssistantUsageEvent({required String id, required String timestamp, String? parentId, bool ephemeral = true, required String model, int? inputTokens, int? outputTokens, int? cacheReadTokens, int? cacheWriteTokens, num? cost, num? duration, String? initiator, String? apiCallId, String? providerCallId, String? parentToolCallId, Map<String, dynamic>? quotaSnapshots})
const

Properties

apiCallId String?
final
cacheReadTokens int?
final
cacheWriteTokens int?
final
cost num?
final
duration num?
final
ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
initiator String?
final
inputTokens int?
final
model String
final
outputTokens int?
final
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
parentToolCallId String?
final
providerCallId String?
final
quotaSnapshots Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
ISO-8601 timestamp.
finalinherited
type String
Event type discriminator.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited