Attachment class sealed

Attachment for a message (sealed hierarchy).

Implementers

Constructors

Attachment.directory(String path, {String? displayName})
Creates a directory attachment.
factory
Attachment.file(String path, {String? displayName})
Creates a file attachment.
factory
Attachment.selection({required String filePath, String? displayName, SelectionRange? selection, String? text})
Creates a selection attachment.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited