cliUrl property
URL of an existing CLI server to connect to (e.g., "localhost:8080"). When set, the client does not spawn a CLI process.
Implementation
final String? cliUrl;
URL of an existing CLI server to connect to (e.g., "localhost:8080"). When set, the client does not spawn a CLI process.
final String? cliUrl;