ErrorOccurredOutput class

Output for the errorOccurred hook.

Constructors

ErrorOccurredOutput({bool? suppressOutput, String? errorHandling, int? retryCount, String? userNotification})
const

Properties

errorHandling String?
"retry", "skip", or "abort".
final
hashCode int
The hash code for this object.
no setterinherited
retryCount int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suppressOutput bool?
final
userNotification String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited