GetAuthStatusResponse class

Response from auth.getStatus.

Constructors

GetAuthStatusResponse({required bool isAuthenticated, String? authType, String? host, String? login, String? statusMessage})
const
GetAuthStatusResponse.fromJson(Map<String, dynamic> json)
factory

Properties

authType String?
final
hashCode int
The hash code for this object.
no setterinherited
host String?
final
isAuthenticated bool
final
login String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusMessage String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited