McpLocalServerConfig class

Local/stdio MCP server configuration.

Inheritance

Constructors

McpLocalServerConfig({required String command, List<String> args = const [], Map<String, String>? env, String? cwd, List<String>? tools, int? timeout})
const

Properties

args List<String>
final
command String
final
cwd String?
final
env Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
Timeout in seconds for server operations.
finalinherited
tools List<String>?
Optional list of tool names to expose from this server.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited