MessageOptions class

Constructors

MessageOptions({required String prompt, List<Attachment> attachments = const [], MessageDeliveryMode? mode})
const

Properties

attachments List<Attachment>
final
hashCode int
The hash code for this object.
no setterinherited
mode MessageDeliveryMode?
Message delivery mode: MessageDeliveryMode.enqueue (default) or MessageDeliveryMode.immediate.
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited