ModelCapabilities class
Model capabilities and limits.
Constructors
- ModelCapabilities({required bool supportsVision, required bool supportsReasoningEffort, int? maxPromptTokens, int? maxOutputTokens, required int maxContextWindowTokens, VisionLimits? vision})
-
const
-
ModelCapabilities.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxContextWindowTokens → int
-
final
- maxOutputTokens → int?
-
final
- maxPromptTokens → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsReasoningEffort → bool
-
final
- supportsVision → bool
-
final
- vision → VisionLimits?
-
Vision-specific limits (only present when the model supports vision).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited