ModelInfo class

Information about an available model.

Constructors

ModelInfo({required String id, required String name, required ModelCapabilities capabilities, ModelPolicy? policy, ModelBilling? billing, List<String>? supportedReasoningEfforts, String? defaultReasoningEffort})
const
ModelInfo.fromJson(Map<String, dynamic> json)
factory

Properties

billing ModelBilling?
final
capabilities ModelCapabilities
final
defaultReasoningEffort String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
policy ModelPolicy?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedReasoningEfforts List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited