PermissionResult class

Permission result to send back.

Constructors

PermissionResult({required String kind, List<Map<String, dynamic>>? rules})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
final
rules List<Map<String, dynamic>>?
Optional rules to apply (e.g., 'always-allow' for specific tools).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

approved → const PermissionResult
Pre-built: approve the permission request.
denied → const PermissionResult
Pre-built: deny the permission request.