PlanReadResult class

Result of reading a session plan.

Constructors

PlanReadResult({required bool exists, String? content})
const

Properties

content String?
The content of plan.md, or null if it does not exist.
final
exists bool
Whether plan.md exists in the workspace.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited