PostToolUseOutput class

Output for the postToolUse hook.

Constructors

PostToolUseOutput({dynamic modifiedResult, String? additionalContext, bool? suppressOutput})
const

Properties

additionalContext String?
final
hashCode int
The hash code for this object.
no setterinherited
modifiedResult → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suppressOutput bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited