PreToolUseOutput class

Output for the preToolUse hook.

Constructors

PreToolUseOutput({String? permissionDecision, String? permissionDecisionReason, dynamic modifiedArgs, String? additionalContext, bool? suppressOutput})
const

Properties

additionalContext String?
Extra context to include in the conversation.
final
hashCode int
The hash code for this object.
no setterinherited
modifiedArgs → dynamic
final
permissionDecision String?
"allow", "deny", or "ask".
final
permissionDecisionReason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suppressOutput bool?
If true, suppress tool output from the user-visible log.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited