SessionCompactionCompleteEvent class final

Inheritance

Constructors

SessionCompactionCompleteEvent({required String id, required String timestamp, String? parentId, bool ephemeral = false, required bool success, String? error, int? preCompactionTokens, int? postCompactionTokens, int? preCompactionMessagesLength, int? messagesRemoved, int? tokensRemoved, String? summaryContent, int? checkpointNumber, String? checkpointPath, Map<String, dynamic>? compactionTokensUsed, String? requestId})
const

Properties

checkpointNumber int?
final
checkpointPath String?
final
compactionTokensUsed Map<String, dynamic>?
final
ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
error String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
messagesRemoved int?
final
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
postCompactionTokens int?
final
preCompactionMessagesLength int?
final
preCompactionTokens int?
final
requestId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
summaryContent String?
final
timestamp String
ISO-8601 timestamp.
finalinherited
tokensRemoved int?
final
type String
Event type discriminator.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited