SessionEndInput class

Input for the sessionEnd hook.

Inheritance

Constructors

SessionEndInput({required num timestamp, required String cwd, required String reason, String? finalMessage, String? error})
const
SessionEndInput.fromJson(Map<String, dynamic> json)
factory

Properties

cwd String
Working directory of the session.
finalinherited
error String?
final
finalMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
reason String
"complete", "error", "abort", "timeout", or "user_exit".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp num
Unix timestamp (milliseconds since epoch) when the hook was triggered.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited