SessionHandoffEvent class final

Inheritance

Constructors

SessionHandoffEvent({required String id, required String timestamp, String? parentId, bool ephemeral = false, required String handoffTime, required String sourceType, Map<String, dynamic>? repository, String? context, String? summary, String? remoteSessionId})
const

Properties

context String?
final
ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
handoffTime String
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
remoteSessionId String?
final
repository Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceType String
One of "remote", "local".
final
summary String?
final
timestamp String
ISO-8601 timestamp.
finalinherited
type String
Event type discriminator.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited