SessionLifecycleEvent class

A session lifecycle event emitted by the CLI.

Constructors

SessionLifecycleEvent({required SessionLifecycleEventType type, required String sessionId, Map<String, dynamic>? metadata})
const
SessionLifecycleEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
type SessionLifecycleEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited