SessionMetadata class

Metadata about a session.

Constructors

SessionMetadata({required String sessionId, required DateTime startTime, required DateTime modifiedTime, String? summary, required bool isRemote, SessionContext? context})
const
SessionMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

context SessionContext?
final
hashCode int
The hash code for this object.
no setterinherited
isRemote bool
final
modifiedTime DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
startTime DateTime
final
summary String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited