SessionStartEvent class final

Inheritance

Constructors

SessionStartEvent({required String id, required String timestamp, String? parentId, bool ephemeral = false, required String sessionId, required int version, required String producer, required String copilotVersion, required String startTime, String? selectedModel, Map<String, dynamic>? context})
const

Properties

context Map<String, dynamic>?
final
copilotVersion String
final
ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
producer String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedModel String?
final
sessionId String
final
startTime String
final
timestamp String
ISO-8601 timestamp.
finalinherited
type String
Event type discriminator.
finalinherited
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited