SessionStartInput class

Input for the sessionStart hook.

Inheritance

Constructors

SessionStartInput({required num timestamp, required String cwd, required String source, String? initialPrompt})
const
SessionStartInput.fromJson(Map<String, dynamic> json)
factory

Properties

cwd String
Working directory of the session.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initialPrompt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
"startup", "resume", or "new".
final
timestamp num
Unix timestamp (milliseconds since epoch) when the hook was triggered.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited