SessionTruncationEvent class final

Inheritance

Constructors

SessionTruncationEvent({required String id, required String timestamp, String? parentId, bool ephemeral = false, required int tokenLimit, required int preTruncationTokensInMessages, required int preTruncationMessagesLength, required int postTruncationTokensInMessages, required int postTruncationMessagesLength, required int tokensRemovedDuringTruncation, required int messagesRemovedDuringTruncation, required String performedBy})
const

Properties

ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
messagesRemovedDuringTruncation int
final
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
performedBy String
final
postTruncationMessagesLength int
final
postTruncationTokensInMessages int
final
preTruncationMessagesLength int
final
preTruncationTokensInMessages int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
ISO-8601 timestamp.
finalinherited
tokenLimit int
final
tokensRemovedDuringTruncation int
final
type String
Event type discriminator.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited