ToolExecutionCompleteEvent class final

Inheritance

Constructors

ToolExecutionCompleteEvent({required String id, required String timestamp, String? parentId, bool ephemeral = false, required String toolCallId, required bool success, bool? isUserRequested, Map<String, dynamic>? result, Map<String, dynamic>? error, Map<String, dynamic>? toolTelemetry, String? parentToolCallId})
const

Properties

ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
error Map<String, dynamic>?
Error info: { message, code? }.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
isUserRequested bool?
final
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
parentToolCallId String?
final
result Map<String, dynamic>?
Structured result: { content, detailedContent?, contents? }.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
timestamp String
ISO-8601 timestamp.
finalinherited
toolCallId String
final
toolTelemetry Map<String, dynamic>?
final
type String
Event type discriminator.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited