ToolExecutionPartialResultEvent class final

Inheritance

Constructors

ToolExecutionPartialResultEvent({required String id, required String timestamp, String? parentId, bool ephemeral = true, required String toolCallId, required String partialOutput})
const

Properties

ephemeral bool
Whether this event is ephemeral (not persisted in session history).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique event ID.
finalinherited
parentId String?
Parent event ID (for nested events like tool execution under a turn).
finalinherited
partialOutput String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
ISO-8601 timestamp.
finalinherited
toolCallId String
final
type String
Event type discriminator.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited