UserInputRequest class

User input request from the CLI.

Constructors

UserInputRequest({required String question, List<String>? choices, bool? allowFreeform})
const
UserInputRequest.fromJson(Map<String, dynamic> json)
factory

Properties

allowFreeform bool?
final
choices List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
question String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited