VisionLimits class

Vision-specific model limits.

Constructors

VisionLimits({required List<String> supportedMediaTypes, required int maxPromptImages, required int maxPromptImageSize})
const
VisionLimits.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
maxPromptImages int
final
maxPromptImageSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedMediaTypes List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited