CustomAgentConfig class
Custom agent configuration.
Constructors
Properties
- description → String?
-
final
- displayName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- infer → bool?
-
Whether to infer agent behavior from context.
final
-
mcpServers
→ Map<
String, McpServerConfig> ? -
MCP servers available to this agent, keyed by name.
final
- name → String
-
final
- prompt → String?
-
System prompt for this agent (required upstream, optional in config).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited