InfiniteSessionConfig class
Infinite session configuration with compaction thresholds.
Constructors
- InfiniteSessionConfig({bool? enabled, double? backgroundCompactionThreshold, double? bufferExhaustionThreshold})
-
const
Properties
- backgroundCompactionThreshold → double?
-
Context utilization threshold (0.0–1.0) at which background compaction
starts. Default: 0.80.
final
- bufferExhaustionThreshold → double?
-
Context utilization threshold (0.0–1.0) at which the session blocks until
compaction completes. Default: 0.95.
final
- enabled → bool?
-
Whether infinite sessions are enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited