JsonRpcTransport class abstract
Abstract interface for JSON-RPC transports.
Implementations provide the physical transport layer (stdio, TCP, WebSocket)
while the JsonRpcConnection handles the JSON-RPC 2.0 protocol on top.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool
-
Whether the transport is currently connected/open.
no setter
-
messages
→ Stream<
Map< String, dynamic> > -
Stream of incoming JSON-RPC messages (already decoded from JSON).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> - Closes the transport and releases resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
Map< String, dynamic> message) → Future<void> - Sends a JSON-RPC message (will be encoded to JSON by the transport).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited