McpRemoteServerConfig class
Remote HTTP or SSE MCP server configuration.
- Inheritance
-
- Object
- McpServerConfig
- McpRemoteServerConfig
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
Optional headers for authentication.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → int?
-
Timeout in seconds for server operations.
finalinherited
-
tools
→ List<
String> ? -
Optional list of tool names to expose from this server.
finalinherited
- type → String
-
Transport type: 'http' or 'sse'.
final
- url → String
-
Server URL.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited