ProviderConfig class
BYOK (Bring Your Own Key) provider configuration.
Constructors
- ProviderConfig({required String type, String? apiKey, String? baseUrl, String? wireApi, String? bearerToken, AzureProviderOptions? azure})
-
const
Properties
- apiKey → String?
-
final
- azure → AzureProviderOptions?
-
Azure-specific provider options.
final
- baseUrl → String?
-
final
- bearerToken → String?
-
Bearer token for authentication.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
- wireApi → String?
-
Wire API format (e.g., 'openai').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited