ResumeSessionConfig class
Configuration for resuming an existing session.
Constructors
-
ResumeSessionConfig({required String sessionId, String? clientName, String? model, SystemMessageConfig? systemMessage, InfiniteSessionConfig? infiniteSessions, bool? streaming, List<
String> ? availableTools, List<String> ? excludedTools, Map<String, McpServerConfig> mcpServers = const {}, List<CustomAgentConfig> customAgents = const [], List<String> skillDirectories = const [], List<String> disabledSkills = const [], ProviderConfig? provider, ReasoningEffort? reasoningEffort, String? configDir, String? workingDirectory, bool? disableResume, required PermissionHandler onPermissionRequest, UserInputHandler? onUserInputRequest, List<Tool> tools = const [], SessionHooks? hooks}) -
const
Properties
-
availableTools
→ List<
String> ? -
final
- clientName → String?
-
final
- configDir → String?
-
final
-
customAgents
→ List<
CustomAgentConfig> -
final
-
disabledSkills
→ List<
String> -
final
- disableResume → bool?
-
final
-
excludedTools
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hooks → SessionHooks?
-
final
- infiniteSessions → InfiniteSessionConfig?
-
final
-
mcpServers
→ Map<
String, McpServerConfig> -
final
- model → String?
-
final
- onPermissionRequest → PermissionHandler
-
final
- onUserInputRequest → UserInputHandler?
-
final
- provider → ProviderConfig?
-
final
- reasoningEffort → ReasoningEffort?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
-
skillDirectories
→ List<
String> -
final
- streaming → bool?
-
final
- systemMessage → SystemMessageConfig?
-
final
-
tools
→ List<
Tool> -
final
- workingDirectory → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON for the session.resume RPC call.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited