SessionShutdownEvent class final
- Inheritance
-
- Object
- SessionEvent
- SessionShutdownEvent
Constructors
-
SessionShutdownEvent({required String id, required String timestamp, String? parentId, bool ephemeral = true, required String shutdownType, String? errorReason, required int totalPremiumRequests, required int totalApiDurationMs, required int sessionStartTime, Map<
String, dynamic> ? codeChanges, Map<String, dynamic> ? modelMetrics, String? currentModel}) -
const
Properties
-
codeChanges
→ Map<
String, dynamic> ? -
final
- currentModel → String?
-
final
- ephemeral → bool
-
Whether this event is ephemeral (not persisted in session history).
finalinherited
- errorReason → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique event ID.
finalinherited
-
modelMetrics
→ Map<
String, dynamic> ? -
final
- parentId → String?
-
Parent event ID (for nested events like tool execution under a turn).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionStartTime → int
-
final
- shutdownType → String
-
One of "routine", "error".
final
- timestamp → String
-
ISO-8601 timestamp.
finalinherited
- totalApiDurationMs → int
-
final
- totalPremiumRequests → int
-
final
- type → String
-
Event type discriminator.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited