ToolBinaryResult class
Binary data result from a tool (images, files, etc.).
Constructors
- ToolBinaryResult({required String data, required String mimeType, String? type, String? description})
-
const
Properties
- data → String
-
Base64-encoded binary data.
final
- description → String?
-
Optional description of the binary content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String
-
MIME type (e.g., 'image/png', 'application/pdf').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Result type identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited