ToolResultObject class
A full tool result object with all fields.
- Inheritance
-
- Object
- ToolResult
- ToolResultObject
Constructors
-
ToolResultObject({required String textResultForLlm, required ToolResultType resultType, String? error, Map<
String, dynamic> ? toolTelemetry, List<ToolBinaryResult> ? binaryResultsForLlm, String? sessionLog}) -
const
Properties
-
binaryResultsForLlm
→ List<
ToolBinaryResult> ? -
Binary results (images, files) to include in the LLM context.
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resultType → ToolResultType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionLog → String?
-
Log message to record in the session history.
final
- textResultForLlm → String
-
final
-
toolTelemetry
→ Map<
String, dynamic> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited